import type { Env, Key, MinimalRequest, Session, User } from "../types.js";
import { Cookie, CookieOption } from "./cookie.js";
import { Adapter, SessionAdapter, UserAdapter, UserData, UserSchema } from "../types.js";
import { LuciaErrorConstructor } from "./error.js";
export { SESSION_COOKIE_NAME } from "./cookie.js";
export declare const lucia: <C extends Configuration>(config: C) => Auth<C>;
export declare class Auth<C extends Configuration = any> {
    private adapter;
    private generateUserId;
    private sessionCookie;
    private sessionTimeout;
    ENV: Env;
    private hash;
    private autoDatabaseCleanup;
    protected transformUserData: (userData: UserSchema) => C["transformUserData"] extends {} ? ReturnType<C["transformUserData"]> : {
        userId: string;
    };
    private csrfProtection;
    constructor(config: C);
    getUser: (userId: string) => Promise<User>;
    getSessionUser: (sessionId: string) => Promise<{
        user: User;
        session: Session;
    }>;
    createUser: (data: {
        key: {
            providerId: string;
            providerUserId: string;
            password: string | null;
        } | null;
        attributes: Lucia.UserAttributes;
    }) => Promise<User>;
    updateUserAttributes: (userId: string, attributes: Partial<Lucia.UserAttributes>) => Promise<User>;
    deleteUser: (userId: string) => Promise<void>;
    validateKeyPassword: (providerId: string, providerUserId: string, password: string) => Promise<Key>;
    getSession: (sessionId: string) => Promise<Session>;
    getAllUserSessions: (userId: string) => Promise<Session[]>;
    validateSession: (sessionId: string) => Promise<Session>;
    validateSessionUser: (sessionId: string) => Promise<{
        session: Session;
        user: User;
    }>;
    generateSessionId: () => [sessionId: string, activePeriodExpires: Date, idlePeriodExpires: Date];
    createSession: (userId: string) => Promise<Session>;
    renewSession: (sessionId: string) => Promise<Session>;
    invalidateSession: (sessionId: string) => Promise<void>;
    invalidateAllUserSessions: (userId: string) => Promise<void>;
    deleteDeadUserSessions: (userId: string) => Promise<void>;
    validateRequestHeaders: (request: MinimalRequest) => string;
    createSessionCookies: (session: Session | null) => Cookie[];
    createKey: (userId: string, keyData: {
        providerId: string;
        providerUserId: string;
        password: string | null;
        timeout?: number | null;
    }) => Promise<Key>;
    deleteKey: (providerId: string, providerUserId: string) => Promise<void>;
    getKey: (providerId: string, providerUserId: string) => Promise<Key>;
    getKeyUser: (providerId: string, providerUserId: string) => Promise<{
        key: Key;
        user: User;
    }>;
    getAllUserKeys: (userId: string) => Promise<Key[]>;
    updateKeyPassword: (providerId: string, providerUserId: string, password: string | null) => Promise<void>;
}
type MaybePromise<T> = T | Promise<T>;
export type Configuration = {
    adapter: ((E: LuciaErrorConstructor) => Adapter) | {
        user: (E: LuciaErrorConstructor) => UserAdapter | Adapter;
        session: (E: LuciaErrorConstructor) => SessionAdapter | Adapter;
    };
    env: Env;
    generateCustomUserId?: () => MaybePromise<string>;
    csrfProtection?: boolean;
    sessionTimeout?: {
        activePeriod: number;
        idlePeriod: number;
    };
    transformUserData?: (userData: UserData) => Record<string, any>;
    sessionCookie?: CookieOption[];
    hash?: {
        generate: (s: string) => MaybePromise<string>;
        validate: (s: string, hash: string) => MaybePromise<boolean>;
    };
    autoDatabaseCleanup?: boolean;
};
